Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1035)

Unified Diff: content/browser/resources/media/dump_creator.js

Issue 1272223003: Implement writing mic audio input data to file for debugging purposes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/resources/media/dump_creator.js
diff --git a/content/browser/resources/media/dump_creator.js b/content/browser/resources/media/dump_creator.js
index e412f3623bcb998e8a795a2653a44d9b534cef32..019d7b30ec12229bd1ac71ae866d04feef02cd9c 100644
--- a/content/browser/resources/media/dump_creator.js
+++ b/content/browser/resources/media/dump_creator.js
@@ -57,17 +57,17 @@ var DumpCreator = (function() {
content.getElementsByTagName('a')[0].addEventListener(
'click', this.onDownloadData_.bind(this));
content.getElementsByTagName('input')[0].addEventListener(
- 'click', this.onAecRecordingChanged_.bind(this));
+ 'click', this.onAudioDebugRecordingsChanged_.bind(this));
}
DumpCreator.prototype = {
- // Mark the AEC recording checkbox checked.
- enableAecRecording: function() {
+ // Mark the diagnostic audio recording checkbox checked.
+ enableAudioDebugRecordings: function() {
this.root_.getElementsByTagName('input')[0].checked = true;
},
- // Mark the AEC recording checkbox unchecked.
- disableAecRecording: function() {
+ // Mark the diagnostic audio recording checkbox unchecked.
+ disableAudioDebugRecordings: function() {
this.root_.getElementsByTagName('input')[0].checked = false;
},
@@ -93,16 +93,16 @@ var DumpCreator = (function() {
},
/**
* Handles the event of toggling the AEC recording state.
*
* @private
*/
- onAecRecordingChanged_: function() {
+ onAudioDebugRecordingsChanged_: function() {
var enabled = this.root_.getElementsByTagName('input')[0].checked;
if (enabled) {
- chrome.send('enableAecRecording');
+ chrome.send('enableAudioDebugRecordings');
} else {
- chrome.send('disableAecRecording');
+ chrome.send('disableAudioDebugRecordings');
}
},
};
@@ -93,16 +93,16 @@ var DumpCreator = (function() {
},
/**
- * Handles the event of toggling the AEC recording state.
+ * Handles the event of toggling the audio debug recordings state.
*
* @private
« no previous file with comments | « content/browser/renderer_host/render_process_host_impl.cc ('k') | content/browser/resources/media/webrtc_internals.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698